==> shared-ldap-0.9.7-sources.jar: org/apache/directory/shared/ldap/codec/search/controls/EntryChangeControlContainer.java <==
/*
 *  Licensed to the Apache Software Foundation (ASF) under one
 *  or more contributor license agreements.  See the NOTICE file
 *  distributed with this work for additional information
 *  regarding copyright ownership.  The ASF licenses this file
 *  to you under the Apache License, Version 2.0 (the
 *  "License"); you may not use this file except in compliance
 *  with the License.  You may obtain a copy of the License at
 *  
 *    http://www.apache.org/licenses/LICENSE-2.0
 *  
 *  Unless required by applicable law or agreed to in writing,
 *  software distributed under the License is distributed on an
 *  "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 *  KIND, either express or implied.  See the License for the
 *  specific language governing permissions and limitations
 *  under the License. 
 *  
 */
package org.apache.directory.shared.ldap.codec.search.controls;


import org.apache.directory.shared.asn1.ber.AbstractContainer;
import org.apache.directory.shared.asn1.ber.IAsn1Container;


/**
 * @author <a href="mailto:dev@directory.apache.org">Apache Directory Project</a>
 */
public class EntryChangeControlContainer extends AbstractContainer implements IAsn1Container
{
    /** EntryChangeControl */
    private EntryChangeControl control;


    /**
     * Creates a new EntryChangeControlContainer object. We will store one
     * grammar, it's enough ...
     */
    public EntryChangeControlContainer()
    {
        super();
        stateStack = new int[1];
        grammar = EntryChangeControlGrammar.getInstance();
        states = EntryChangeControlStatesEnum.getInstance();
    }


    /**
     * @return Returns the EntryChangeControl.
     */
    public EntryChangeControl getEntryChangeControl()
    {
        return control;
    }


    /**
     * Set a EntryChangeControl Object into the container. It will be completed
     * by the ldapDecoder.
     * 
     * @param control the EntryChangeControl to set.
     */
    public void setEntryChangeControl( EntryChangeControl control )
    {
        this.control = control;
    }

    /**
     * Clean the container
     */
    public void clean()
    {
        super.clean();
        control = null;
    }
}

==> shared-ldap-0.9.8-sources.jar: org/apache/directory/shared/ldap/codec/search/controls/EntryChangeControlContainer.java <==
/*
 *  Licensed to the Apache Software Foundation (ASF) under one
 *  or more contributor license agreements.  See the NOTICE file
 *  distributed with this work for additional information
 *  regarding copyright ownership.  The ASF licenses this file
 *  to you under the Apache License, Version 2.0 (the
 *  "License"); you may not use this file except in compliance
 *  with the License.  You may obtain a copy of the License at
 *  
 *    http://www.apache.org/licenses/LICENSE-2.0
 *  
 *  Unless required by applicable law or agreed to in writing,
 *  software distributed under the License is distributed on an
 *  "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 *  KIND, either express or implied.  See the License for the
 *  specific language governing permissions and limitations
 *  under the License. 
 *  
 */
package org.apache.directory.shared.ldap.codec.search.controls;


import org.apache.directory.shared.asn1.ber.AbstractContainer;
import org.apache.directory.shared.asn1.ber.IAsn1Container;


/**
 * @author <a href="mailto:dev@directory.apache.org">Apache Directory Project</a>
 */
public class EntryChangeControlContainer extends AbstractContainer implements IAsn1Container
{
    /** EntryChangeControl */
    private EntryChangeControlCodec control;


    /**
     * Creates a new EntryChangeControlContainer object. We will store one
     * grammar, it's enough ...
     */
    public EntryChangeControlContainer()
    {
        super();
        stateStack = new int[1];
        grammar = EntryChangeControlGrammar.getInstance();
        states = EntryChangeControlStatesEnum.getInstance();
    }


    /**
     * @return Returns the EntryChangeControl.
     */
    public EntryChangeControlCodec getEntryChangeControl()
    {
        return control;
    }


    /**
     * Set a EntryChangeControl Object into the container. It will be completed
     * by the ldapDecoder.
     * 
     * @param control the EntryChangeControl to set.
     */
    public void setEntryChangeControl( EntryChangeControlCodec control )
    {
        this.control = control;
    }

    /**
     * Clean the container
     */
    public void clean()
    {
        super.clean();
        control = null;
    }
}
